svn commit: r290833 - in user/alc/PQ_LAUNDRY/usr.bin: systat top vmstat

Mark Johnston markj at FreeBSD.org
Sat Nov 14 22:22:20 UTC 2015


Author: markj
Date: Sat Nov 14 22:22:18 2015
New Revision: 290833
URL: https://svnweb.freebsd.org/changeset/base/290833

Log:
  Update top(1), systat(1) and vmstat(8) to report the length of the laundry
  queue.  Also remove references to the page cache, as it will be removed
  in the near future.

Modified:
  user/alc/PQ_LAUNDRY/usr.bin/systat/systat.1
  user/alc/PQ_LAUNDRY/usr.bin/systat/vmstat.c
  user/alc/PQ_LAUNDRY/usr.bin/top/machine.c
  user/alc/PQ_LAUNDRY/usr.bin/top/top.local.1
  user/alc/PQ_LAUNDRY/usr.bin/vmstat/vmstat.c

Modified: user/alc/PQ_LAUNDRY/usr.bin/systat/systat.1
==============================================================================
--- user/alc/PQ_LAUNDRY/usr.bin/systat/systat.1	Sat Nov 14 22:12:19 2015	(r290832)
+++ user/alc/PQ_LAUNDRY/usr.bin/systat/systat.1	Sat Nov 14 22:22:18 2015	(r290833)
@@ -28,7 +28,7 @@
 .\"	@(#)systat.1	8.2 (Berkeley) 12/30/93
 .\" $FreeBSD$
 .\"
-.Dd October 24, 2015
+.Dd November 14, 2015
 .Dt SYSTAT 1
 .Os
 .Sh NAME
@@ -411,7 +411,7 @@ as amounts of memory in kilobytes,
 pages wired down (`wire'),
 active pages (`act'),
 inactive pages (`inact'),
-pages on the cache queue (`cache'),
+pages in the laundry queue (`laund'),
 and
 free pages (`free').
 Note that the values displayed are the current transient ones;

Modified: user/alc/PQ_LAUNDRY/usr.bin/systat/vmstat.c
==============================================================================
--- user/alc/PQ_LAUNDRY/usr.bin/top/machine.c	Sat Nov 14 22:12:19 2015	(r290832)
+++ user/alc/PQ_LAUNDRY/usr.bin/top/machine.c	Sat Nov 14 22:22:18 2015	(r290833)
@@ -176,7 +176,7 @@ char *cpustatenames[] = {
 
 int memory_stats[7];
 char *memorynames[] = {
-	"K Active, ", "K Inact, ", "K Wired, ", "K Cache, ", "K Buf, ",
+	"K Active, ", "K Inact, ", "K Laundry, ", "K Wired, ", "K Buf, ",
 	"K Free", NULL
 };
 
@@ -490,8 +490,8 @@ get_system_info(struct system_info *si)
 		GETSYSCTL("vfs.bufspace", bufspace);
 		GETSYSCTL("vm.stats.vm.v_active_count", memory_stats[0]);
 		GETSYSCTL("vm.stats.vm.v_inactive_count", memory_stats[1]);
-		GETSYSCTL("vm.stats.vm.v_wire_count", memory_stats[2]);
-		GETSYSCTL("vm.stats.vm.v_cache_count", memory_stats[3]);
+		GETSYSCTL("vm.stats.vm.v_laundry_count", memory_stats[2]);
+		GETSYSCTL("vm.stats.vm.v_wire_count", memory_stats[3]);
 		GETSYSCTL("vm.stats.vm.v_free_count", memory_stats[5]);
 		GETSYSCTL("vm.stats.vm.v_swappgsin", nspgsin);
 		GETSYSCTL("vm.stats.vm.v_swappgsout", nspgsout);

Modified: user/alc/PQ_LAUNDRY/usr.bin/top/top.local.1
==============================================================================
--- user/alc/PQ_LAUNDRY/usr.bin/top/top.local.1	Sat Nov 14 22:12:19 2015	(r290832)
+++ user/alc/PQ_LAUNDRY/usr.bin/top/top.local.1	Sat Nov 14 22:22:18 2015	(r290833)
@@ -2,8 +2,8 @@
 .SH "FreeBSD NOTES"
 
 .SH DESCRIPTION OF MEMORY
-Mem: 9220K Active, 1M Inact, 3284K Wired, 1M Cache, 2M Buf, 1320K Free
-ARC: 2048K Total, 342K MRU, 760K MFU, 272K Anon, 232K Header, 442K Other
+Mem: 9220K Active, 1M Inact, 1M Laundry, 3284K Wired, 2M Buf, 932K Free
+ARC: 2048K Total, 342K MRU, 760K MFU, 272K Anon, 96K Header, 442K Other
 Swap: 91M Total, 79M Free, 13% Inuse, 80K In, 104K Out
 .TP
 .B K:
@@ -23,15 +23,14 @@ Gigabyte
 number of bytes active
 .TP
 .B Inact:
-number of bytes inactive
+number of clean bytes inactive
+.TP
+.B Laundry:
+number of dirty bytes inactive
 .TP
 .B Wired:
 number of bytes wired down, including BIO-level cached file data pages
 .TP
-.B Cache:
-number of clean bytes caching data that are available for
-immediate reallocation
-.TP
 .B Buf:
 number of bytes used for BIO-level disk caching
 .TP

Modified: user/alc/PQ_LAUNDRY/usr.bin/vmstat/vmstat.c
==============================================================================
--- user/alc/PQ_LAUNDRY/usr.bin/vmstat/vmstat.c	Sat Nov 14 22:12:19 2015	(r290832)
+++ user/alc/PQ_LAUNDRY/usr.bin/vmstat/vmstat.c	Sat Nov 14 22:22:18 2015	(r290833)
@@ -541,7 +541,6 @@ fill_vmmeter(struct vmmeter *vmmp)
 		GET_VM_STATS(vm, v_reactivated);
 		GET_VM_STATS(vm, v_pdwakeups);
 		GET_VM_STATS(vm, v_pdpages);
-		GET_VM_STATS(vm, v_tcached);
 		GET_VM_STATS(vm, v_dfree);
 		GET_VM_STATS(vm, v_pfree);
 		GET_VM_STATS(vm, v_tfree);
@@ -555,7 +554,7 @@ fill_vmmeter(struct vmmeter *vmmp)
 		GET_VM_STATS(vm, v_active_count);
 		GET_VM_STATS(vm, v_inactive_target);
 		GET_VM_STATS(vm, v_inactive_count);
-		GET_VM_STATS(vm, v_cache_count);
+		GET_VM_STATS(vm, v_laundry_count);
 		GET_VM_STATS(vm, v_pageout_free_min);
 		GET_VM_STATS(vm, v_interrupt_free_min);
 		/*GET_VM_STATS(vm, v_free_severe);*/
@@ -1006,13 +1005,12 @@ dosum(void)
 	(void)printf("%9u pages affected by  fork()\n", sum.v_forkpages);
 	(void)printf("%9u pages affected by vfork()\n", sum.v_vforkpages);
 	(void)printf("%9u pages affected by rfork()\n", sum.v_rforkpages);
-	(void)printf("%9u pages cached\n", sum.v_tcached);
 	(void)printf("%9u pages freed\n", sum.v_tfree);
 	(void)printf("%9u pages freed by daemon\n", sum.v_dfree);
 	(void)printf("%9u pages freed by exiting processes\n", sum.v_pfree);
 	(void)printf("%9u pages active\n", sum.v_active_count);
 	(void)printf("%9u pages inactive\n", sum.v_inactive_count);
-	(void)printf("%9u pages in VM cache\n", sum.v_cache_count);
+	(void)printf("%9u pages in the laundry\n", sum.v_laundry_count);
 	(void)printf("%9u pages wired down\n", sum.v_wire_count);
 	(void)printf("%9u pages free\n", sum.v_free_count);
 	(void)printf("%9u bytes per page\n", sum.v_page_size);


More information about the svn-src-user mailing list
--- user/alc/PQ_LAUNDRY/usr.bin/systat/vmstat.c	Sat Nov 14 22:12:19 2015	(r290832)
+++ user/alc/PQ_LAUNDRY/usr.bin/systat/vmstat.c	Sat Nov 14 22:22:18 2015	(r290833)
@@ -107,7 +107,7 @@ static struct Info {
 	u_int v_wire_count;	/* number of pages wired down */
 	u_int v_active_count;	/* number of pages active */
 	u_int v_inactive_count;	/* number of pages inactive */
-	u_int v_cache_count;	/* number of pages on buffer cache queue */
+	u_int v_laundry_count;	/* number of pages in laundry queue */
 	struct	vmtotal Total;
 	struct	nchstats nchstats;
 	long	nchcount;
@@ -337,7 +337,7 @@ labelkre(void)
 	mvprintw(VMSTATROW + 12, VMSTATCOL + 9, "wire");
 	mvprintw(VMSTATROW + 13, VMSTATCOL + 9, "act");
 	mvprintw(VMSTATROW + 14, VMSTATCOL + 9, "inact");
-	mvprintw(VMSTATROW + 15, VMSTATCOL + 9, "cache");
+	mvprintw(VMSTATROW + 15, VMSTATCOL + 9, "laund");
 	mvprintw(VMSTATROW + 16, VMSTATCOL + 9, "free");
 	if (LINES - 1 > VMSTATROW + 17)
 		mvprintw(VMSTATROW + 17, VMSTATCOL + 9, "buf");
@@ -508,7 +508,7 @@ showkre(void)
 	putint(pgtokb(s.v_wire_count), VMSTATROW + 12, VMSTATCOL, 8);
 	putint(pgtokb(s.v_active_count), VMSTATROW + 13, VMSTATCOL, 8);
 	putint(pgtokb(s.v_inactive_count), VMSTATROW + 14, VMSTATCOL, 8);
-	putint(pgtokb(s.v_cache_count), VMSTATROW + 15, VMSTATCOL, 8);
+	putint(pgtokb(s.v_laundry_count), VMSTATROW + 15, VMSTATCOL, 8);
 	putint(pgtokb(s.v_free_count), VMSTATROW + 16, VMSTATCOL, 8);
 	if (LINES - 1 > VMSTATROW + 17)
 		putint(s.bufspace / 1024, VMSTATROW + 17, VMSTATCOL, 8);
@@ -783,7 +783,7 @@ getinfo(struct Info *ls)
 	GETSYSCTL("vm.stats.vm.v_wire_count", ls->v_wire_count);
 	GETSYSCTL("vm.stats.vm.v_active_count", ls->v_active_count);
 	GETSYSCTL("vm.stats.vm.v_inactive_count", ls->v_inactive_count);
-	GETSYSCTL("vm.stats.vm.v_cache_count", ls->v_cache_count);
+	GETSYSCTL("vm.stats.vm.v_laundry_count", ls->v_laundry_count);
 	GETSYSCTL("vfs.bufspace", ls->bufspace);
 	GETSYSCTL("kern.maxvnodes", ls->desiredvnodes);
 	GETSYSCTL("vfs.numvnodes", ls->numvnodes);

Modified: user/alc/PQ_LAUNDRY/usr.bin/top/machine.c
==============================================================================